@@ -1,5 +1,5 @@
 package App::Provision::Perlbrew;
-$App::Provision::Perlbrew::VERSION = '0.04';
+$App::Provision::Perlbrew::VERSION = '0.0401';
 BEGIN {
   $App::Provision::Perlbrew::AUTHORITY = 'cpan:GENE';
 }
@@ -15,13 +15,16 @@ sub deps
 sub meet
 {
     my $self = shift;
+
+    $self->{release} ||= '5.18.2';
+
     $self->recipe(
       [ 'curl -L http://install.perlbrew.pl | bash' ],
       [ 'touch', "$ENV{HOME}/.bash_profile" ],
       [ "echo 'source ~/perl5/perlbrew/etc/bashrc' >> $ENV{HOME}/.bash_profile" ],
       [ "`source', $ENV{HOME}/.bash_profile`" ],
-      [qw( perlbrew install perl-5.18.2 )],
-      [qw( perlbrew switch perl-5.18.2 )],
+      [qw( perlbrew install ), "perl-$self->{release}" ],
+      [qw( perlbrew switch ), "perl-$self->{release}" ],
     );
 }
 
@@ -39,7 +42,7 @@ App::Provision::Perlbrew
 
 =head1 VERSION
 
-version 0.04
+version 0.0401
 
 =head1 AUTHOR
 
