@@ -1,5 +1,5 @@
 package App::Provision::SourceTree;
-$App::Provision::SourceTree::VERSION = '0.04';
+$App::Provision::SourceTree::VERSION = '0.0401';
 BEGIN {
   $App::Provision::SourceTree::AUTHORITY = 'cpan:GENE';
 }
@@ -16,6 +16,9 @@ sub condition
 {
     my $self = shift;
 
+    die "Program '$self->{program}' must include a --release\n"
+        unless $self->{release};
+
     # The program name is a special case for OSX.apps.
     $self->{program} = '/Applications/SourceTree.app';
 
@@ -31,8 +34,8 @@ sub meet
     if ( $self->{system} eq 'osx' )
     {
         $self->recipe(
-          [ 'wget', 'http://downloads.atlassian.com/software/sourcetree/SourceTree_1.8.1.dmg', '-P', "$ENV{HOME}/Downloads/" ],
-          [ 'hdiutil', 'attach', "$ENV{HOME}/Downloads/SourceTree_1.8.1.dmg", ],
+          [ 'wget', "http://downloads.atlassian.com/software/sourcetree/SourceTree_$self->{release}.dmg", '-P', "$ENV{HOME}/Downloads/" ],
+          [ 'hdiutil', 'attach', "$ENV{HOME}/Downloads/SourceTree_$self->{release}.dmg", ],
           [ 'cp', '-r', '/Volumes/SourceTree/SourceTree.app', '/Applications/' ],
           [ 'hdiutil', 'detach', '/Volumes/SourceTree' ],
         );
@@ -53,7 +56,7 @@ App::Provision::SourceTree
 
 =head1 VERSION
 
-version 0.04
+version 0.0401
 
 =head1 AUTHOR
 
